==> eiffelstudio-23.09.10.7341.tar: F_code/C12/dt573.c <==
/*
 * Code for class DT_WEEK_DAYS_FROM_MONDAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt573.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_WEEK_DAYS_FROM_MONDAY}.monday */
static EIF_REFERENCE F1284_11040_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11040);
#define Result RTOSR(11040)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11224(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11040);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11040 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11040,F1284_11040_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.tuesday */
static EIF_REFERENCE F1284_11041_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11041);
#define Result RTOSR(11041)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11225(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11041);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11041 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11041,F1284_11041_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.wednesday */
static EIF_REFERENCE F1284_11042_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11042);
#define Result RTOSR(11042)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11226(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11042);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11042 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11042,F1284_11042_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.thursday */
static EIF_REFERENCE F1284_11043_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11043);
#define Result RTOSR(11043)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11227(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11043);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11043 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11043,F1284_11043_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.friday */
static EIF_REFERENCE F1284_11044_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11044);
#define Result RTOSR(11044)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11228(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11044);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11044 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11044,F1284_11044_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.saturday */
static EIF_REFERENCE F1284_11045_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11045);
#define Result RTOSR(11045)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11229(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11045);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11045 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11045,F1284_11045_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.sunday */
static EIF_REFERENCE F1284_11046_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11046);
#define Result RTOSR(11046)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1295, 0x01).id, 1295, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1294_11230(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11046);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11046 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11046,F1284_11046_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.week_day_from_code */
EIF_REFERENCE F1284_11047 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	switch (arg1) {
		case 1L:
			Result = RTOSCF(11040,F1284_11040, (Current));
			break;
		case 2L:
			Result = RTOSCF(11041,F1284_11041, (Current));
			break;
		case 3L:
			Result = RTOSCF(11042,F1284_11042, (Current));
			break;
		case 4L:
			Result = RTOSCF(11043,F1284_11043, (Current));
			break;
		case 5L:
			Result = RTOSCF(11044,F1284_11044, (Current));
			break;
		case 6L:
			Result = RTOSCF(11045,F1284_11045, (Current));
			break;
		case 7L:
			Result = RTOSCF(11046,F1284_11046, (Current));
			break;
		default:
			RTEC(EN_WHEN);
	}
	RTLE;
	return Result;
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.week_day_from_date */
EIF_REFERENCE F1284_11048 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,arg1);
	RTLR(1,Current);
	RTLR(2,Result);
	RTLIU(3);
	
	RTGC;
	ti4_1 = F1616_13490(RTCW(arg1));
	ti4_2 = F1616_13491(RTCW(arg1));
	ti4_3 = F1616_13492(RTCW(arg1));
	Result = F1284_11049(Current, ti4_1, ti4_2, ti4_3);
	RTLE;
	return Result;
}

/* {DT_WEEK_DAYS_FROM_MONDAY}.week_day_from_year_month_day */
EIF_REFERENCE F1284_11049 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1, EIF_INTEGER_32 arg2, EIF_INTEGER_32 arg3)
{
	GTCX
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_INTEGER_32 loc2 = (EIF_INTEGER_32) 0;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	loc1 = F1280_11006(Current, arg1, arg2, arg3);
	loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 3L));
	if ((EIF_BOOLEAN) (loc1 < ((EIF_INTEGER_32) 0L))) {
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (((EIF_INTEGER_32) 7L) - (EIF_INTEGER_32) ((EIF_INTEGER_32) -(EIF_INTEGER_32) (loc1 + ((EIF_INTEGER_32) 1L)) % ((EIF_INTEGER_32) 7L)));
	} else {
		loc2 = (EIF_INTEGER_32) (EIF_INTEGER_32) (((EIF_INTEGER_32) 1L) + (EIF_INTEGER_32) (loc1 % ((EIF_INTEGER_32) 7L)));
	}
	RTLE;
	return (EIF_REFERENCE) F1284_11047(Current, loc2);
}

void EIF_Minit573 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-25.12.9.8922.tar: F_code/C12/dt573.c <==
/*
 * Code for class DT_WEEK_DAYS_FROM_SUNDAY
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "dt573.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {DT_WEEK_DAYS_FROM_SUNDAY}.monday */
static EIF_REFERENCE F1284_11041_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11041);
#define Result RTOSR(11041)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11242(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11041);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11041 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11041,F1284_11041_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.tuesday */
static EIF_REFERENCE F1284_11042_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11042);
#define Result RTOSR(11042)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11243(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11042);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11042 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11042,F1284_11042_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.wednesday */
static EIF_REFERENCE F1284_11043_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11043);
#define Result RTOSR(11043)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11244(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11043);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11043 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11043,F1284_11043_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.thursday */
static EIF_REFERENCE F1284_11044_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11044);
#define Result RTOSR(11044)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11245(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11044);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11044 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11044,F1284_11044_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.friday */
static EIF_REFERENCE F1284_11045_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11045);
#define Result RTOSR(11045)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11246(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11045);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11045 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11045,F1284_11045_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.saturday */
static EIF_REFERENCE F1284_11046_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11046);
#define Result RTOSR(11046)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11247(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11046);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11046 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11046,F1284_11046_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.sunday */
static EIF_REFERENCE F1284_11047_body (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	

	RTLI(1);
	RTLR(0,tr1);
	RTLIU(1);
	
	RTEV;
	RTGC;
	RTOSP (11047);
#define Result RTOSR(11047)
	RTOC_NEW(Result);
	tr1 = RTLNS(eif_new_type(1296, 0x01).id, 1296, _OBJSIZ_0_0_0_1_0_0_0_0_);
	F1295_11248(RTCW(tr1));
	Result = (EIF_REFERENCE) tr1;
	RTOSE (11047);
	RTLE;
	RTEE;
	return Result;
#undef Result
}

EIF_REFERENCE F1284_11047 (EIF_REFERENCE Current)
{
	GTCX
	return RTOSCF(11047,F1284_11047_body,(Current));
}

/* {DT_WEEK_DAYS_FROM_SUNDAY}.week_day_from_code */
EIF_REFERENCE F1284_11048 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLIU(2);
	
	RTGC;
	switch (arg1) {
		case 2L:
			Result = RTOSCF(11041,F1284_11041, (Current));
			break;
		case 3L:
			Result = RTOSCF(11042,F1284_11042, (Current));
			break;
		case 4L:
			Result = RTOSCF(11043,F1284_11043, (Current));
			break;
		case 5L:
			Result = RTOSCF(11044,F1284_11044, (Current));
			break;
		case 6L:
			Result = RTOSCF(11045,F1284_11045, (Current));
			break;
		case 7L:
			Result = RTOSCF(11046,F1284_11046, (Current));
			break;
		case 1L:
			Result = RTOSCF(11047,F1284_11047, (Current));
			break;
		default:
			RTEC(EN_WHEN);
	}
	RTLE;
	return Result;
}

void EIF_Minit573 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
